pub struct MemoryPressureMarker;Trait Implementations
Sourceimpl Clone for MemoryPressureMarker
impl Clone for MemoryPressureMarker
Sourcefn clone(&self) -> MemoryPressureMarker
fn clone(&self) -> MemoryPressureMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MemoryPressureMarker
Sourceimpl Debug for MemoryPressureMarker
impl Debug for MemoryPressureMarker
Sourceimpl DiscoverableProtocolMarker for MemoryPressureMarker
impl DiscoverableProtocolMarker for MemoryPressureMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for MemoryPressureMarker
Sourceimpl Hash for MemoryPressureMarker
impl Hash for MemoryPressureMarker
Sourceimpl Ord for MemoryPressureMarker
impl Ord for MemoryPressureMarker
Sourcefn cmp(&self, other: &MemoryPressureMarker) -> Ordering
fn cmp(&self, other: &MemoryPressureMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MemoryPressureMarker
impl PartialEq for MemoryPressureMarker
Sourcefn eq(&self, other: &MemoryPressureMarker) -> bool
fn eq(&self, other: &MemoryPressureMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MemoryPressureMarker
impl PartialOrd for MemoryPressureMarker
Sourceimpl ProtocolMarker for MemoryPressureMarker
impl ProtocolMarker for MemoryPressureMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.memory.debug.MemoryPressure"
const DEBUG_NAME: &'static str = "fuchsia.memory.debug.MemoryPressure"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = MemoryPressureProxy
type Proxy = MemoryPressureProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = MemoryPressureRequestStream
type RequestStream = MemoryPressureRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = MemoryPressureSynchronousProxy
type SynchronousProxy = MemoryPressureSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for MemoryPressureMarker