pub struct MemoryPressureProxy { /* private fields */ }Implementations
Sourceimpl MemoryPressureProxy
impl MemoryPressureProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.memory.debug/MemoryPressure.
Sourcepub fn take_event_stream(&self) -> MemoryPressureEventStream
pub fn take_event_stream(&self) -> MemoryPressureEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn signal(&self, level: Level) -> Result<(), Error>
pub fn signal(&self, level: Level) -> Result<(), Error>
Signals registered watchers of the fuchsia.memorypressure service with the specified memory pressure level. Intended for debugging only. Does not on its own change the memory pressure level of the system, or trigger any kernel memory reclamation tasks. However the components listening will receive a memory pressure signal which can lead to a change in the memory usage of the device, and an actual change in the memory pressure level of the system.