pub struct MemoryPressureSynchronousProxy { /* private fields */ }Implementations
Sourceimpl MemoryPressureSynchronousProxy
impl MemoryPressureSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<MemoryPressureEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<MemoryPressureEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn signal(&self, level: Level) -> Result<(), Error>
pub fn signal(&self, level: Level) -> Result<(), Error>
Signals registered watchers of the fuchsia.memorypressure service with the specified memory pressure level. Intended for debugging only. Does not on its own change the memory pressure level of the system, or trigger any kernel memory reclamation tasks. However the components listening will receive a memory pressure signal which can lead to a change in the memory usage of the device, and an actual change in the memory pressure level of the system.