pub enum MemoryPressureRequest {
Signal {
level: Level,
control_handle: MemoryPressureControlHandle,
},
}Expand description
Helps debug memory-pressure related features on a fuchsia device.
Variants
Signal
Signals registered watchers of the fuchsia.memorypressure service with the specified memory pressure level. Intended for debugging only. Does not on its own change the memory pressure level of the system, or trigger any kernel memory reclamation tasks. However the components listening will receive a memory pressure signal which can lead to a change in the memory usage of the device, and an actual change in the memory pressure level of the system.
Implementations
Sourceimpl MemoryPressureRequest
impl MemoryPressureRequest
pub fn into_signal(self) -> Option<(Level, MemoryPressureControlHandle)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL